@@ -409,16 +409,30 @@ class Sequential():
     def fit(self, cost_fn, epochs = 1000, lr = 0.1, momentum = None, verbose = 1, live_stats = None):
         if live_stats == None:
             live_stats = LiveStats()
+        elif live_stats == -1:
+            live_stats = LiveStats(type=-1)
+        elif live_stats == 0:
+            live_stats = LiveStats(type=0)
+        elif live_stats == 1:
+            live_stats = LiveStats(type=1)
+        elif live_stats == 2:
+            live_stats = LiveStats(type=2)
             
         for n in [-1,0,1,2]:
             if live_stats.type == n:
                 break
             elif n == 2 and live_stats.type != n:
-                raise ValueError("unknown value for live_stats['type']")
+                raise ValueError("unknown value for live_stats.type")
 
         if live_stats.row_select != "full" and live_stats.row_select != "limited":
             raise ValueError("unknown value for live_stats.row_select")
-                
+        
+        if type(live_stats.f1) != int:
+            raise ValueError("unknown value for live_stats.f1")
+        
+        if type(live_stats.f2) != int:
+            raise ValueError("unknown value for live_stats.f2")
+            
         self.__is_trained__ = True
         import copy
         from tqdm import tqdm
@@ -438,7 +452,7 @@ class Sequential():
                 if cost_fn == name:
                     self.val_cost_fn = function
                     break
-
+        
         if live_stats.type == -1:
             update = 50
             figure = plt.figure()
